@@ -157,8 +157,8 @@ NULL
 
         collected <- bpmapply(FUN=.quick_cluster, x.by.block, 
             MoreArgs=list(min.size=min.size, method=method, use.ranks=use.ranks,
-                subset.row=subset.row, min.mean=min.mean, 
-                BSPARAM=BSPARAM, BPPARAM=BPPARAM, ...), 
+                d = d, subset.row=subset.row, min.mean=min.mean, 
+                graph.fun = graph.fun, BSPARAM=BSPARAM, BPPARAM=BPPARAM, ...), 
             BPPARAM=block.BPPARAM)
 
         # Merging the results across different blocks.
@@ -230,7 +230,8 @@ NULL
 # Internal functions.
 ############################
 
-#' @importFrom Matrix colMeans t
+#' @importFrom Matrix t
+#' @importFrom MatrixGenerics colMeans
 #' @importFrom DelayedArray getAutoBPPARAM setAutoBPPARAM
 #' @importFrom BiocParallel SerialParam
 .create_rank_matrix <- function(x, deferred, ..., BPPARAM=SerialParam()) {
