@@ -23,13 +23,9 @@ REFFUN <- function(y, grouping, direction="any", lfc=0)
                         cur.p <- t.test(host.y[i,], target.y[i,], alternative=alt.hyp)$p.value
                     } else {
                         if (direction=="any") {
-                            left.p <- t.test(host.y[i,], target.y[i,], alternative="less", mu=-lfc)$p.value + 
-                                t.test(host.y[i,], target.y[i,], alternative="less", mu=lfc)$p.value
-                            left.p <- left.p / 2
-                            right.p <- t.test(host.y[i,], target.y[i,], alternative="greater", mu=-lfc)$p.value + 
-                                t.test(host.y[i,], target.y[i,], alternative="greater", mu=lfc)$p.value
-                            right.p <- right.p / 2
-                            cur.p <- pmin(left.p, right.p) * 2
+                            left.p <- t.test(host.y[i,], target.y[i,], alternative="less", mu=-lfc)$p.value
+                            right.p <- t.test(host.y[i,], target.y[i,], alternative="greater", mu=lfc)$p.value
+                            cur.p <- pmin(left.p, right.p, 0.5) * 2
                         } else if (direction=="up") {
                             cur.p <- t.test(host.y[i,], target.y[i,], alternative=alt.hyp, mu=lfc)$p.value 
                         } else {
@@ -41,7 +37,7 @@ REFFUN <- function(y, grouping, direction="any", lfc=0)
             } else {
                 pval <- effect <- rep(NA_real_, nrow(y))
             }
-            
+
 			currow <- which(output$pairs[,1]==host & output$pairs[,2]==target)
             curres <- output$statistics[[currow]]
 			expect_equal(unname(curres$logFC), unname(effect))
@@ -78,19 +74,19 @@ test_that("pairwiseTTests works as expected without blocking or design matrices"
     re.clust <- clust$cluster
     re.clust[1] <- 4
     re.clust <- factor(re.clust)
-    REFFUN(X, re.clust)
+    expect_warning(REFFUN(X, re.clust), "no within-block")
 
     # Checking what happens if two of the groups have only one element.
     re.clust <- clust$cluster
     re.clust[1:2] <- 4:5
     re.clust <- factor(re.clust)
-    REFFUN(X, re.clust)
+    expect_warning(REFFUN(X, re.clust), "no within-block")
 
     # Checking what happens if there is an empty level.
     re.clusters <- clusters
     levels(re.clusters) <- 1:4
 
-    out <- pairwiseTTests(X, re.clusters)
+    expect_warning(out <- pairwiseTTests(X, re.clusters), "no within-block")
     ref <- pairwiseTTests(X, clusters)
     subset <- match(paste0(ref$pairs$first, ".", ref$pairs$second), 
         paste0(out$pairs$first, ".", out$pairs$second))
@@ -211,18 +207,22 @@ BLOCKFUN <- function(y, grouping, block, direction="any", ...) {
             }
 
             block.weights[[B]] <- 1/(1/N1 + 1/N2)
-            block.res <- pairwiseTTests(y[,chosen], subgroup, direction=direction, ...)
-            to.use <- which(block.res$pairs$first==curpair[1] & block.res$pairs$second==curpair[2])
 
-            block.lfc[[B]] <- block.res$statistics[[to.use]]$logFC
             if (direction=="any") { 
-                # Recovering one-sided p-values for separate combining across blocks.
-                going.up <- block.lfc[[B]] > 0
-                curp <- block.res$statistics[[to.use]]$p.value/2
-                block.up[[B]] <- ifelse(going.up, curp, 1-curp)
-                block.down[[B]] <- ifelse(!going.up, curp, 1-curp)
+                up.res <- pairwiseTTests(y[,chosen], subgroup, direction="up", ...)
+                to.use <- which(up.res$pairs$first==curpair[1] & up.res$pairs$second==curpair[2])
+                block.up[[B]] <- up.res$statistics[[to.use]]$p.value
+
+                down.res <- pairwiseTTests(y[,chosen], subgroup, direction="down", ...)
+                to.use <- which(down.res$pairs$first==curpair[1] & down.res$pairs$second==curpair[2])
+                block.down[[B]] <- down.res$statistics[[to.use]]$p.value
+
+                block.lfc[[B]] <- down.res$statistics[[to.use]]$logFC
             } else {
+                block.res <- pairwiseTTests(y[,chosen], subgroup, direction=direction, ...)
+                to.use <- which(block.res$pairs$first==curpair[1] & block.res$pairs$second==curpair[2])
                 block.up[[B]] <- block.down[[B]] <- block.res$statistics[[to.use]]$p.value
+                block.lfc[[B]] <- block.res$statistics[[to.use]]$logFC
             }
         }
 
@@ -239,10 +239,10 @@ BLOCKFUN <- function(y, grouping, block, direction="any", ...) {
         expect_equal(ave.lfc, ref.res$logFC)
 
         # Combining p-values in each direction.
-        up.p <- do.call(combinePValues, c(block.up, list(method="z", weights=block.weights)))
-        down.p <- do.call(combinePValues, c(block.down, list(method="z", weights=block.weights)))
+        up.p <- metapod::parallelStouffer(block.up, weights=block.weights)$p.value
+        down.p <- metapod::parallelStouffer(block.down, weights=block.weights)$p.value
         if (direction=="any") {
-            expect_equal(pmin(up.p, down.p) * 2, ref.res$p.value)
+            expect_equal(pmin(up.p, down.p, 0.5) * 2, ref.res$p.value)
         } else if (direction=="up") {
             expect_equal(up.p, ref.res$p.value)
         } else if (direction=="down") {
@@ -361,12 +361,7 @@ LINEARFUN <- function(y, grouping, design, direction="any", lfc=0) {
             right <- pt((cur.lfc - lfc) / (fit$sigma * fit$stdev.unscaled[,target]), lower.tail=FALSE, df = fit$df.residual)
 
             if (direction=="any") {
-                left2 <- pt((cur.lfc - lfc) / (fit$sigma * fit$stdev.unscaled[,target]), lower.tail=TRUE, df = fit$df.residual)
-                right2 <- pt((cur.lfc + lfc) / (fit$sigma * fit$stdev.unscaled[,target]), lower.tail=FALSE, df = fit$df.residual)
-                left.p <- (left + left2)/2
-                right.p <- (right + right2)/2
-                pval <- pmin(left.p, right.p) * 2
-
+                pval <- pmin(left, right, 0.5) * 2
             } else if (direction=="up") {
                 pval <- right
             } else {
@@ -563,6 +558,13 @@ test_that("pairwiseTTests behaves with standardization of the log-fold changes",
     s.pool <- sqrt((s1 * (sum(in.1) - 1) + s2 * (sum(in.2) - 1))/(sum(in.1|in.2) -2))
     expect_equal(ref[[1]][[1]]$logFC / s.pool, std[[1]][[1]]$logFC)
 
+    # Handles zero-variance cases properly.
+    ref <- pairwiseTTests(rbind(rep(0, 20)), g, std.lfc=TRUE)
+    expect_identical(unname(ref[[1]][[1]]$logFC), 0)
+
+    ref <- pairwiseTTests(rbind(c(0,0,1,1)), c(1,1,2,2), std.lfc=TRUE)
+    expect_identical(unname(ref[[1]][[1]]$logFC), -Inf)
+
     # With linear models.
     ref <- pairwiseTTests(y, g, design=X) 
     std <- pairwiseTTests(y, g, design=X, std.lfc=TRUE)
